@@ -45,8 +45,8 @@ import functools
 import logging
 import traceback
 import types
-from typing import Any, Callable, Dict, List, Optional, Sequence
 import weakref
+from typing import Any, Callable, Dict, List, Optional, Sequence
 
 import asgiref.sync
 import channels.generic.websocket as ch_websocket
@@ -61,7 +61,6 @@ import rx
 from .scope_as_context import ScopeAsContext
 from .serializer import Serializer
 
-
 # Module logger.
 LOG = logging.getLogger(__name__)
 
@@ -861,7 +860,11 @@ class GraphqlWsConsumer(ch_websocket.AsyncJsonWebsocketConsumer):
                 "payload": {
                     "data": data,
                     **(
-                        {"errors": [self._format_error(e) for e in errors]}
+                        {
+                            "errors": [  # type: ignore
+                                self._format_error(e) for e in errors
+                            ]
+                        }
                         if errors
                         else {}
                     ),
